/*
 *
 * tc902x_macros.h
 *
 * Include file with macros for Gigabit Ethernet
 * device driver for Network Interface Cards (NICs) utilizing the
 * Tamarack Microelectronics Inc. TC902X Gigabit or Triple Speed
 * Ethernet Media Access Controller.
 *
 * Craig Rich
 * Sundance Technology, Inc.
 * 1485 Saratoga Avenue
 * Suite 200
 * San Jose, CA 95129
 * 408 873 4117
 * www.sundanceti.com
 * craig_rich@sundanceti.com
 *
 * Rev  Date     Description
 * --------------------------------------------------------------
 * 0.1  3/30/01  New file created from original tc902x.h
 */

/*
 * Miscellaneous macros.
 */

/* Marco for printing debug statements.
#  define TC902X_DDEBUG_MSG(args...) printk(KERN_DEBUG "TC902X: " ## args) */
#ifdef TC902X_DEBUG
#  define TC902X_DEBUG_MSG(args...) 
#  define TC902X_DDEBUG_MSG(args...) printk(KERN_DEBUG "TC902X: " args)
#  define TC902X_DUMPRFDLIST(args) tc902x_dump_rfdlist(args)
#  define TC902X_DUMPTFDLIST(args) tc902x_dump_tfdlist(args)
#else
#  define TC902X_DEBUG_MSG(args...)
#  define TC902X_DDEBUG_MSG(args...)
#  define TC902X_DUMPRFDLIST(args)
#  define TC902X_DUMPTFDLIST(args)
#endif

/*
 * End miscellaneous macros.
 */

/*
 * Register access macros.
 */

#ifdef USE_IO_OPS

/* Use I/O access for TC902X registers. */

#define RD8 inb
#define RD16 inw
#define RD32 inl
#define WR8 outb
#define WR16 outw
#define WR32 outl

#else

/* Use memory access for TC902X registers. */

#define RD8 readb
#define RD16 readw
#define RD32 readl
#define WR8 writeb
#define WR16 writew
#define WR32 writel

#endif

#define		TC902X_READ_BYTEREG(regaddr)	RD8(regaddr)

#define		TC902X_READ_WORDREG(regaddr) RD16(regaddr)

#define		TC902X_READ_LONGREG(regaddr)	RD32(regaddr)

#define		TC902X_WRITE_BYTEREG(regaddr, writevalue)	WR8(writevalue, regaddr)

#define		TC902X_WRITE_WORDREG(regaddr, writevalue)	WR16(writevalue, regaddr)

#define		TC902X_WRITE_LONGREG(regaddr, writevalue)	WR32(writevalue, regaddr)

#define		TC902X_READ_ASICCTRL(baseaddr)	RD32(baseaddr + TC902X_ASICCTRL)

#define		TC902X_WRITE_ASICCTRL(baseaddr, writevalue)	WR32(TC902X_AC_RSVD_MASK & (writevalue), baseaddr + TC902X_ASICCTRL)

#define		TC902X_READ_EEPROMCTRL(baseaddr)	RD16(baseaddr + TC902X_EEPROMCTRL)

#define		TC902X_WRITE_EEPROMCTRL(baseaddr, writevalue)	WR16(TC902X_EC_RSVD_MASK & (writevalue), baseaddr + TC902X_EEPROMCTRL)

#define		TC902X_READ_EEPROMDATA(baseaddr)	RD16(baseaddr + TC902X_EEPROMDATA)

#define		TC902X_WRITE_EEPROMDATA(baseaddr, writevalue)	WR16(writevalue, (baseaddr + TC902X_EEPROMDATA)

#define		TC902X_READ_PHYCTRL(baseaddr)	RD8(baseaddr + TC902X_PHYCTRL)

#define		TC902X_WRITE_PHYCTRL(baseaddr, writevalue)	WR8(TC902X_PC_RSVD_MASK & (writevalue), baseaddr + TC902X_PHYCTRL)

#define		TC902X_READ_RECEIVEMODE(baseaddr)	RD8(baseaddr + TC902X_RECEIVEMODE)

#define		TC902X_WRITE_RECEIVEMODE(baseaddr, writevalue)	WR8(TC902X_RM_RSVD_MASK & (writevalue), baseaddr + TC902X_RECEIVEMODE)

#define		TC902X_READ_MAXFRAMESIZE(baseaddr)	RD16(baseaddr + TC902X_MAXFRAMESIZE)

#define		TC902X_WRITE_MAXFRAMESIZE(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_MAXFRAMESIZE)

#define		TC902X_READ_MACCTRL(baseaddr)	RD32(baseaddr + TC902X_MACCTRL)

#define		TC902X_WRITE_MACCTRL(baseaddr, writevalue)	WR32(TC902X_MC_RSVD_MASK & (writevalue), baseaddr + TC902X_MACCTRL)

#define		TC902X_READ_INTSTATUSACK(baseaddr)	RD16(baseaddr + TC902X_INTSTATUSACK)

#define		TC902X_READ_INTSTATUS(baseaddr)	RD16(baseaddr + TC902X_INTSTATUS)

#define		TC902X_WRITE_INTSTATUS(baseaddr, writevalue)	WR16(TC902X_IS_RSVD_MASK & (writevalue), baseaddr + TC902X_INTSTATUS)

#define		TC902X_READ_INTENABLE(baseaddr)	RD16(baseaddr + TC902X_INTENABLE)

#define		TC902X_WRITE_INTENABLE(baseaddr, writevalue)	WR16(TC902X_IE_RSVD_MASK & (writevalue), baseaddr + TC902X_INTENABLE)

#define		TC902X_READ_WAKEEVENT(baseaddr)	RD8(baseaddr + TC902X_WAKEEVENT)

#define		TC902X_WRITE_WAKEEVENT(baseaddr, writevalue)	WR8(writevalue, baseaddr + TC902X_WAKEEVENT)

#define		TC902X_READ_RXEARLYTHRESH(baseaddr)	RD16(baseaddr + TC902X_RXEARLYTHRESH)

#define		TC902X_WRITE_RXEARLYTHRESH(baseaddr, writevalue)	WR16(TC902X_RE_RSVD_MASK & (writevalue), baseaddr + TC902X_RXEARLYTHRESH)

#define		TC902X_READ_TXSTARTTHRESH(baseaddr)	RD32(baseaddr + TC902X_TXSTARTTHRESH)

#define		TC902X_WRITE_TXSTARTTHRESH(baseaddr, writevalue)	WR32(TC902X_TT_RSVD_MASK & (writevalue), baseaddr + TC902X_TXSTARTTHRESH)

#define		TC902X_READ_FIFOCTRL(baseaddr)	RD16(baseaddr + TC902X_FIFOCTRL)

#define		TC902X_WRITE_FIFOCTRL(baseaddr, writevalue)	WR16(TC902X_FC_RSVD_MASK & (writevalue), baseaddr + TC902X_FIFOCTRL)

#define		TC902X_READ_RXDMAPOLLPERIOD(baseaddr)	RD8(baseaddr + TC902X_RXDMAPOLLPERIOD)

#define		TC902X_WRITE_RXDMAPOLLPERIOD(baseaddr, writevalue)	WR8(TC902X_RP_RSVD_MASK & (writevalue), baseaddr + TC902X_RXDMAPOLLPERIOD)

#define		TC902X_READ_RXDMAURGENTTHRESH(baseaddr)	RD8(baseaddr + TC902X_RXDMAURGENTTHRESH)

#define		TC902X_WRITE_RXDMAURGENTTHRESH(baseaddr, writevalue)	WR8(TC902X_RU_RSVD_MASK & (writevalue), baseaddr + TC902X_RXDMAURGENTTHRESH)

#define		TC902X_READ_RXDMABURSTTHRESH(baseaddr)	RD8(baseaddr + TC902X_RXDMABURSTTHRESH)

#define		TC902X_WRITE_RXDMABURSTTHRESH(baseaddr, writevalue)	WR8(writevalue, baseaddr + TC902X_RXDMABURSTTHRESH)

#define		TC902X_READ_RFDLISTPTR0(baseaddr)	RD32(baseaddr + TC902X_RFDLISTPTR0)

#define		TC902X_WRITE_RFDLISTPTR0(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_RFDLISTPTR0)

#define		TC902X_READ_RFDLISTPTR1(baseaddr)	RD32(baseaddr + TC902X_RFDLISTPTR1)

#define		TC902X_WRITE_RFDLISTPTR1(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_RFDLISTPTR1)

#define		TC902X_READ_TXDMAPOLLPERIOD(baseaddr)	RD8(baseaddr + TC902X_TXDMAPOLLPERIOD)

#define		TC902X_WRITE_TXDMAPOLLPERIOD(baseaddr, writevalue)	WR8(TC902X_TP_RSVD_MASK & (writevalue), baseaddr + TC902X_TXDMAPOLLPERIOD)

#define		TC902X_READ_TXDMAURGENTTHRESH(baseaddr)	RD8(baseaddr + TC902X_TXDMAURGENTTHRESH)

#define		TC902X_WRITE_TXDMAURGENTTHRESH(baseaddr, writevalue)	WR8(TC902X_TU_RSVD_MASK & (writevalue), baseaddr + TC902X_TXDMAURGENTTHRESH)

#define		TC902X_READ_TXDMABURSTTHRESH(baseaddr)	RD8(baseaddr + TC902X_TXDMABURSTTHRESH)

#define		TC902X_WRITE_TXDMABURSTTHRESH(baseaddr, writevalue)	WR8(TC902X_TB_RSVD_MASK & (writevalue), baseaddr + TC902X_TXDMABURSTTHRESH)

#define		TC902X_READ_TFDLISTPTR0(baseaddr)	RD32(baseaddr + TC902X_TFDLISTPTR0)

#define		TC902X_WRITE_TFDLISTPTR0(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_TFDLISTPTR0)

#define		TC902X_READ_TFDLISTPTR1(baseaddr)	RD32(baseaddr + TC902X_TFDLISTPTR1)

#define		TC902X_WRITE_TFDLISTPTR1(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_TFDLISTPTR1)

#define		TC902X_READ_DMACTRL(baseaddr)	RD32(baseaddr + TC902X_DMACTRL)

#define		TC902X_WRITE_DMACTRL(baseaddr, writevalue)	WR32(TC902X_DC_RSVD_MASK & (writevalue), baseaddr + TC902X_DMACTRL)

#define		TC902X_READ_TXSTATUS(baseaddr)	RD32(baseaddr + TC902X_TXSTATUS)

#define		TC902X_WRITE_TXSTATUS(baseaddr, writevalue)	WR32(TC902X_TS_RSVD_MASK & (writevalue), baseaddr + TC902X_TXSTATUS)

#define		TC902X_READ_STATIONADDRESS0(baseaddr)	RD16(baseaddr + TC902X_STATIONADDRESS0)

#define		TC902X_READ_STATIONADDRESS1(baseaddr)	RD16(baseaddr + TC902X_STATIONADDRESS1)

#define		TC902X_READ_STATIONADDRESS2(baseaddr)	RD16(baseaddr + TC902X_STATIONADDRESS2)

#define		TC902X_READ_COUNTDOWN(baseaddr)	RD32(baseaddr + TC902X_COUNTDOWN)

#define		TC902X_WRITE_COUNTDOWN(baseaddr, writevalue)	WR32(TC902X_CD_RSVD_MASK & (writevalue), baseaddr + TC902X_COUNTDOWN)

#define		TC902X_READ_RXDMASTATUS(baseaddr)	RD16(baseaddr + TC902X_RXDMASTATUS)

#define		TC902X_WRITE_HASHTABLE0(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_HASHTABLE0)

#define		TC902X_WRITE_HASHTABLE1(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_HASHTABLE1)

#define		TC902X_READ_STATISTICSMASK(baseaddr)	RD32(baseaddr + TC902X_STATISTICSMASK)

#define		TC902X_WRITE_STATISTICSMASK(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_STATISTICSMASK)

#define		TC902X_READ_RMONSTATISTICSMASK(baseaddr)	RD32(baseaddr + TC902X_RMONSTATISTICSMASK)

#define		TC902X_WRITE_RMONSTATISTICSMASK(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_RMONSTATISTICSMASK)

#define		TC902X_READ_VLANTAG(baseaddr)	RD32(baseaddr + TC902X_VLANTAG)

#define		TC902X_WRITE_VLANTAG(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_VLANTAG)

#define		TC902X_READ_FLOWONTHRESH(baseaddr)	RD16(baseaddr + TC902X_FLOWONTHRESH)

#define		TC902X_WRITE_FLOWONTHRESH(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_FLOWONTHRESH)

#define		TC902X_READ_FLOWOFFTHRESH(baseaddr)	RD16(baseaddr + TC902X_FLOWOFFTHRESH)

#define		TC902X_WRITE_FLOWOFFTHRESH(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_FLOWOFFTHRESH)

#define		TC902X_READ_DEBUGCTRL(baseaddr)	RD16(baseaddr + TC902X_DEBUGCTRL)

#define		TC902X_WRITE_DEBUGCTRL(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_DEBUGCTRL)

#define		TC902X_READ_RXDMAINTCTRL(baseaddr)	RD32(baseaddr + TC902X_RXDMAINTCTRL)

#define		TC902X_WRITE_RXDMAINTCTRL(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_RXDMAINTCTRL)

#define		TC902X_READ_TXJUMBOFRAMES(baseaddr)	RD16(baseaddr + TC902X_TXJUMBOFRAMES)

#define		TC902X_WRITE_TXJUMBOFRAMES(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_TXJUMBOFRAMES)

#define		TC902X_READ_UDPCHECKSUMERRORS(baseaddr)	RD16(baseaddr + TC902X_UDPCHECKSUMERRORS)

#define		TC902X_WRITE_UDPCHECKSUMERRORS(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_UDPCHECKSUMERRORS)

#define		TC902X_READ_IPCHECKSUMERRORS(baseaddr)	RD16(baseaddr + TC902X_IPCHECKSUMERRORS)

#define		TC902X_WRITE_IPCHECKSUMERRORS(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_IPCHECKSUMERRORS)

#define		TC902X_READ_TCPCHECKSUMERRORS(baseaddr)	RD16(baseaddr + TC902X_TCPCHECKSUMERRORS)

#define		TC902X_WRITE_TCPCHECKSUMERRORS(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_TCPCHECKSUMERRORS)

#define		TC902X_READ_RXJUMBOFRAMES(baseaddr)	RD16(baseaddr + TC902X_RXJUMBOFRAMES)

#define		TC902X_WRITE_RXJUMBOFRAMES(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_RXJUMBOFRAMES)



/* Statistic register read/write macros. */

#define		TC902X_READ_OCTETRCVOK(baseaddr)	RD32(baseaddr + TC902X_OCTETRCVOK)

#define		TC902X_WRITE_OCTETRCVOK(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_OCTETRCVOK)

#define		TC902X_READ_MCSTOCTETRCVDOK(baseaddr)	RD32(baseaddr + TC902X_MCSTOCTETRCVDOK)

#define		TC902X_WRITE_MCSTOCTETRCVDOK(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_MCSTOCTETRCVDOK)

#define		TC902X_READ_BCSTOCTETRCVOK(baseaddr)	RD32(baseaddr + TC902X_BCSTOCTETRCVOK)

#define		TC902X_WRITE_BCSTOCTETRCVOK(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_BCSTOCTETRCVOK)

#define		TC902X_READ_FRAMESRCVDOK(baseaddr)	RD32(baseaddr + TC902X_FRAMESRCVDOK)

#define		TC902X_WRITE_FRAMESRCVDOK(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_FRAMESRCVDOK)

#define		TC902X_READ_MCSTFRAMESRCVDOK(baseaddr)	RD32(baseaddr + TC902X_MCSTFRAMESRCVDOK)

#define		TC902X_WRITE_MCSTFRAMESRCVDOK(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_MCSTFRAMESRCVDOK)

#define		TC902X_READ_BCSTFRAMESRCVDOK(baseaddr)	RD16(baseaddr + TC902X_BCSTFRAMESRCVDOK)

#define		TC902X_WRITE_BCSTFRAMESRCVDOK(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_BCSTFRAMESRCVDOK)

#define		TC902X_READ_MACCONTROLFRAMESRCVD(baseaddr)	RD16(baseaddr + TC902X_MACCONTROLFRAMESRCVD)

#define		TC902X_WRITE_MACCONTROLFRAMESRCVD(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_MACCONTROLFRAMESRCVD)

#define		TC902X_READ_FRAMETOOLONGERRRORS(baseaddr)	RD16(baseaddr + TC902X_FRAMETOOLONGERRRORS)

#define		TC902X_WRITE_FRAMETOOLONGERRRORS(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_FRAMETOOLONGERRRORS)

#define		TC902X_READ_INRANGELENGTHERRORS(baseaddr)	RD16(baseaddr + TC902X_INRANGELENGTHERRORS)

#define		TC902X_WRITE_INRANGELENGTHERRORS(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_INRANGELENGTHERRORS)

#define		TC902X_READ_FRAMECHECKSEQERRORS(baseaddr)	RD16(baseaddr + TC902X_FRAMECHECKSEQERRORS)

#define		TC902X_WRITE_FRAMECHECKSEQERRORS(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_FRAMECHECKSEQERRORS)

#define		TC902X_READ_FRAMESLOSTRXERRORS(baseaddr)	RD16(baseaddr + TC902X_FRAMESLOSTRXERRORS)

#define		TC902X_WRITE_FRAMESLOSTRXERRORS(baseaddr, writevalue) WR16(writevalue, baseaddr + TC902X_FRAMESLOSTRXERRORS)

#define		TC902X_READ_FRAMESLOSTRXERRORS(baseaddr)	RD16(baseaddr + TC902X_FRAMESLOSTRXERRORS)

#define		TC902X_WRITE_FRAMESLOSTRXERRORS(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_FRAMESLOSTRXERRORS)

#define		TC902X_READ_OCTETXMTOK(baseaddr)	RD32(baseaddr + TC902X_OCTETXMTOK)

#define		TC902X_WRITE_OCTETXMTOK(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_OCTETXMTOK)

#define		TC902X_READ_MCSTOCTETXMTOK(baseaddr)	RD32(baseaddr + TC902X_MCSTOCTETXMTOK)

#define		TC902X_WRITE_MCSTOCTETXMTOK(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_MCSTOCTETXMTOK)

#define		TC902X_READ_BCSTOCTETXMTOK(baseaddr)	RD32(baseaddr + TC902X_BCSTOCTETXMTOK)

#define		TC902X_WRITE_BCSTOCTETXMTOK(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_BCSTOCTETXMTOK)

#define		TC902X_READ_FRAMESXMTDOK(baseaddr)	RD32(baseaddr + TC902X_FRAMESXMTDOK)

#define		TC902X_WRITE_FRAMESXMTDOK(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_FRAMESXMTDOK)

#define		TC902X_READ_MCSTFRAMESXMTDOK(baseaddr)	RD32(baseaddr + TC902X_MCSTFRAMESXMTDOK)

#define		TC902X_WRITE_MCSTFRAMESXMTDOK(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_MCSTFRAMESXMTDOK)

#define		TC902X_READ_FRAMESWDEFERREDXMT(baseaddr)	RD32(baseaddr + TC902X_FRAMESWDEFERREDXMT)

#define		TC902X_WRITE_FRAMESWDEFERREDXMT(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_FRAMESWDEFERREDXMT)

#define		TC902X_READ_LATECOLLISIONS(baseaddr)	RD32(baseaddr + TC902X_LATECOLLISIONS)

#define		TC902X_WRITE_LATECOLLISIONS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_LATECOLLISIONS)

#define		TC902X_READ_MULTICOLFRAMES(baseaddr)	RD32(baseaddr + TC902X_MULTICOLFRAMES)

#define		TC902X_WRITE_MULTICOLFRAMES(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_MULTICOLFRAMES)

#define		TC902X_READ_SINGLECOLFRAMES(baseaddr)	RD32(baseaddr + TC902X_SINGLECOLFRAMES)

#define		TC902X_WRITE_SINGLECOLFRAMES(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_SINGLECOLFRAMES)

#define		TC902X_READ_BCSTFRAMESXMTDOK(baseaddr)	RD16(baseaddr + TC902X_BCSTFRAMESXMTDOK)

#define		TC902X_WRITE_BCSTFRAMESXMTDOK(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_BCSTFRAMESXMTDOK)

#define		TC902X_READ_CARRIERSENSEERRORS(baseaddr)	RD16(baseaddr + TC902X_CARRIERSENSEERRORS)

#define		TC902X_WRITE_CARRIERSENSEERRORS(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_CARRIERSENSEERRORS)

#define		TC902X_READ_MACCONTROLFRAMESXMTDOK(baseaddr)	RD16(baseaddr + TC902X_MACCONTROLFRAMESXMTDOK)

#define		TC902X_WRITE_MACCONTROLFRAMESXMTDOK(baseaddr, writevalue) WR16(writevalue, baseaddr + TC902X_MACCONTROLFRAMESXMTDOK)

#define		TC902X_READ_FRAMESABORTXSCOLLS(baseaddr)	RD16(baseaddr + TC902X_FRAMESABORTXSCOLLS)

#define		TC902X_WRITE_FRAMESABORTXSCOLLS(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_FRAMESABORTXSCOLLS)

#define		TC902X_READ_FRAMESWEXDEFERRAL(baseaddr)	RD16(baseaddr + TC902X_FRAMESWEXDEFERRAL)

#define		TC902X_WRITE_FRAMESWEXDEFERRAL(baseaddr, writevalue)	WR16(writevalue, baseaddr + TC902X_FRAMESWEXDEFERRAL)

/* RMON statistic register read/write macros. */

#define		TC902X_READ_ETHERSTATSCOLLISIONS(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSCOLLISIONS)

#define		TC902X_WRITE_ETHERSTATSCOLLISIONS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSCOLLISIONS)

#define		TC902X_READ_ETHERSTATSOCTETSTRANSMIT(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSOCTETSTRANSMIT)

#define		TC902X_WRITE_ETHERSTATSOCTETSTRANSMIT(baseaddr, writevalue) WR32(writevalue, baseaddr + TC902X_ETHERSTATSOCTETSTRANSMIT)

#define		TC902X_READ_ETHERSTATSPKTSTRANSMIT(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSPKTSTRANSMIT)

#define		TC902X_WRITE_ETHERSTATSPKTSTRANSMIT(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTSTRANSMIT)

#define		TC902X_READ_ETHERSTATSPKTS64OCTESTSTRANSMIT(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSPKTS64OCTESTSTRANSMIT)

#define		TC902X_WRITE_ETHERSTATSPKTS64OCTESTSTRANSMIT(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTS64OCTESTSTRANSMIT)

#define		TC902X_READ_ETHERSTATSPKTS65TO127OCTESTSTRANSMIT(baseaddr) RD32(baseaddr + TC902X_ETHERSTATSPKTS65TO127OCTESTSTRANSMIT)

#define		TC902X_WRITE_ETHERSTATSPKTS65TO127OCTESTSTRANSMIT(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTS65TO127OCTESTSTRANSMIT)

#define		TC902X_READ_ETHERSTATSPKTS128TO255OCTESTSTRANSMIT(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSPKTS128TO255OCTESTSTRANSMIT)

#define		TC902X_WRITE_ETHERSTATSPKTS128TO255OCTESTSTRANSMIT(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTS128TO255OCTESTSTRANSMIT)

#define		TC902X_READ_ETHERSTATSPKTS256TO511OCTESTSTRANSMIT(baseaddr) RD32(baseaddr + TC902X_ETHERSTATSPKTS256TO511OCTESTSTRANSMIT)

#define		TC902X_WRITE_ETHERSTATSPKTS256TO511OCTESTSTRANSMIT(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTS256TO511OCTESTSTRANSMIT)

#define		TC902X_READ_ETHERSTATSPKTS512TO1023OCTESTSTRANSMIT(baseaddr) RD32(baseaddr + TC902X_ETHERSTATSPKTS512TO1023OCTESTSTRANSMIT)

#define		TC902X_WRITE_ETHERSTATSPKTS512TO1023OCTESTSTRANSMIT(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTS512TO1023OCTESTSTRANSMIT)

#define		TC902X_READ_ETHERSTATSPKTS1024TO1518OCTESTSTRANSMIT(baseaddr) RD32(baseaddr + TC902X_ETHERSTATSPKTS1024TO1518OCTESTSTRANSMIT)

#define		TC902X_WRITE_ETHERSTATSPKTS1024TO1518OCTESTSTRANSMIT(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTS1024TO1518OCTESTSTRANSMIT)

#define		TC902X_READ_ETHERSTATSCRCALIGNERRORS(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSCRCALIGNERRORS)

#define		TC902X_WRITE_ETHERSTATSCRCALIGNERRORS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSCRCALIGNERRORS)

#define		TC902X_READ_ETHERSTATSUNDERSIZEPKTS(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSUNDERSIZEPKTS)

#define		TC902X_WRITE_ETHERSTATSUNDERSIZEPKTS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSUNDERSIZEPKTS)

#define		TC902X_READ_ETHERSTATSFRAGMENTS(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSFRAGMENTS)

#define		TC902X_WRITE_ETHERSTATSFRAGMENTS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSFRAGMENTS)

#define		TC902X_READ_ETHERSTATSJABBERS(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSJABBERS)

#define		TC902X_WRITE_ETHERSTATSJABBERS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSJABBERS)

#define		TC902X_READ_ETHERSTATSOCTETS(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSOCTETS)

#define		TC902X_WRITE_ETHERSTATSOCTETS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSOCTETS)

#define		TC902X_READ_ETHERSTATSPKTS(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSPKTS)

#define		TC902X_WRITE_ETHERSTATSPKTS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTS)

#define		TC902X_READ_ETHERSTATSPKTS64OCTESTS(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSPKTS64OCTESTS)

#define		TC902X_WRITE_ETHERSTATSPKTS64OCTESTS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTS64OCTESTS)

#define		TC902X_READ_ETHERSTATSPKTS65TO127OCTESTS(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSPKTS65TO127OCTESTS)

#define		TC902X_WRITE_ETHERSTATSPKTS65TO127OCTESTS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTS65TO127OCTESTS)

#define		TC902X_READ_ETHERSTATSPKTS128TO255OCTESTS(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSPKTS128TO255OCTESTS)

#define		TC902X_WRITE_ETHERSTATSPKTS128TO255OCTESTS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTS128TO255OCTESTS)

#define		TC902X_READ_ETHERSTATSPKTS256TO511OCTESTS(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSPKTS256TO511OCTESTS)

#define		TC902X_WRITE_ETHERSTATSPKTS256TO511OCTESTS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTS256TO511OCTESTS)

#define		TC902X_READ_ETHERSTATSPKTS512TO1023OCTESTS(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSPKTS512TO1023OCTESTS)

#define		TC902X_WRITE_ETHERSTATSPKTS512TO1023OCTESTS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTS512TO1023OCTESTS)

#define		TC902X_READ_ETHERSTATSPKTS1024TO1518OCTESTS(baseaddr)	RD32(baseaddr + TC902X_ETHERSTATSPKTS1024TO1518OCTESTS)

#define		TC902X_WRITE_ETHERSTATSPKTS1024TO1518OCTESTS(baseaddr, writevalue)	WR32(writevalue, baseaddr + TC902X_ETHERSTATSPKTS1024TO1518OCTESTS)

/*
 * End register access macros.
 */

/* end tc902x_macros.h */
