/*
 *
 * tc902x.h
 *
 * Include file with structures for Gigabit Ethernet
 * device driver for Network Interface Cards (NICs) utilizing the
 * Tamarack Microelectronics Inc. TC902X Gigabit or Triple Speed
 * Ethernet Media Access Controller.
 *
 * Craig Rich
 * Sundance Technology, Inc.
 * 1485 Saratoga Avenue
 * Suite 200
 * San Jose, CA 95129
 * 408 873 4117
 * www.sundanceti.com
 * craig_rich@sundanceti.com
 *
 * Rev  Date     Description
 * --------------------------------------------------------------
 * 0.1  3/30/01  New file created from original tc902x.h
 *
 * 0.2  5/22/01  Added PCI_DEVICE_ID_TAMARACK_TC9020_9021_ALT
 *               to nics_supported[] array.
 */

/* TC902X Ethernet device structure, used for removing module. */
TC902X_DEVICE_TYPE *root_tc902x_ethernet_device = NULL;

/* Transmit Frame Descriptor. The TC902X supports 15 fragments,
 * however Linux requires only a single fragment. Note, each
 * TFD field is 64 bits wide.
 */
struct TFD
{
	u64		TFDNextPtr;
	u64		TFC;
	u64		FragInfo;
};

/* Receive Frame Descriptor. Note, each RFD field is 64 bits wide.
 */
struct RFD
{
	u64		RFDNextPtr;
	u64		RFS;
	u64		FragInfo;
};

#ifdef TC902X_LINUX2_4
struct tc902x_dmabuff
{
	dma_addr_t	dmahandle;
	unsigned long	len;
};

#endif

/* Structure of TC902X NIC specific data. */
struct tc902x_nic_private
{
        struct TFD    		*TFDList;
        struct RFD    		*RFDList;
#ifdef TC902X_LINUX2_4
	dma_addr_t		TFDListDMAhandle;
	dma_addr_t		RFDListDMAhandle;
	struct tc902x_dmabuff	TxBuffDMAhandle[TC902X_TFDLIST_LENGTH];
	struct tc902x_dmabuff	RxBuffDMAhandle[TC902X_RFDLIST_LENGTH];
#endif
	struct sk_buff		*TxBuff[TC902X_TFDLIST_LENGTH];
	struct sk_buff		*RxBuff[TC902X_RFDLIST_LENGTH];
	u16			CurrentTxFrameID;
	int			CurrentTFD;
	int			LastFreedTxBuff;
	int			CurrentRFD;
	int			LastRestoredRxBuff;
	int			RxBuffNotReady;
	struct pci_dev		*tc902x_pci_device;
	TC902X_STATS_TYPE	stats;
	TC902X_DEVICE_TYPE	*next_tc902x_ethernet_device;
        spinlock_t              lock;
	int			tenmbpsmode;
#ifdef TC902X_DEBUG
	int			TFDunavailCount;
	int			RFDlistendCount;
	int			RFDListCheckedCount;
	int			EmptyRFDListCount;
#endif
};

struct	nic_id
{
	char*		NICname;
	int		vendorid;
	int		deviceid;
};

struct	nic_id	nics_supported[] =
{
	{"Sundance Technology ST2021 based NIC",
         PCI_VENDOR_ID_SUNDANCE,
	 PCI_DEVICE_ID_SUNDANCE_ST2021},
	{"Tamarack Microelectronics TC9020/9021 based NIC",
	 PCI_VENDOR_ID_SUNDANCE,
	 PCI_DEVICE_ID_TAMARACK_TC9020_9021},
	{"Tamarack Microelectronics TC9020/9021 based NIC",
	 PCI_VENDOR_ID_SUNDANCE,
	 PCI_DEVICE_ID_TAMARACK_TC9020_9021_ALT},
	{"D-Link NIC",
	 PCI_VENDOR_ID_DLINK,
	 PCI_DEVICE_ID_DLINK_1002},
	{"N/A", 0xFFFF, 0}
};

#ifdef TC902X_LINUX2_4
struct	pci_device_id	pci_devices_supported[] =
{
	{PCI_VENDOR_ID_SUNDANCE,
	 PCI_DEVICE_ID_SUNDANCE_ST2021,
	 PCI_ANY_ID,
	 PCI_ANY_ID,
	 0x020000,
	 0xFFFFFF,
	 0},

	{PCI_VENDOR_ID_SUNDANCE,
	 PCI_DEVICE_ID_TAMARACK_TC9020_9021,
	 PCI_ANY_ID,
	 PCI_ANY_ID,
	 0x020000,
	 0xFFFFFF,
	 1},

	{PCI_VENDOR_ID_DLINK,
	 PCI_DEVICE_ID_DLINK_1002,
	 PCI_ANY_ID,
	 PCI_ANY_ID,
	 0x020000,
	 0xFFFFFF,
	 2},

	{0,}
};
#endif
/* end tc902x_structs.h */
