/*
 *
 * tc902x_constants.h
 *
 * Include file with non-tunable constants for Gigabit Ethernet
 * device driver for Network Interface Cards (NICs) utilizing the
 * Tamarack Microelectronics Inc. TC902X Gigabit or Triple Speed
 * Ethernet Media Access Controller.
 *
 * Craig Rich
 * Sundance Technology, Inc.
 * 1485 Saratoga Avenue
 * Suite 200
 * San Jose, CA 95129
 * 408 873 4117
 * www.sundanceti.com
 * craig_rich@sundanceti.com
 *
 * Rev  Date     Description
 * --------------------------------------------------------------
 * 0.1  3/30/01  New file created from original tc902x.h
 *
 * 0.2  8/13/01  Added GMII based PHY IDs and GMII_ID_1.
 *
 * 0.3  8/16/01  Added GMII_PHY_CONTROL_RESET.
 */

/* GMII based PHY IDs */
#define		NS				0x2000
#define		MARVELL				0x0141

/* NIC Physical Layer Device MII register addresses. */
#define         MII_PHY_CONTROL                 0x00
#define         MII_PHY_STATUS                  0x01
#define         MII_PHY_IDENTIFIER_MSB          0x02
#define         MII_PHY_IDENTIFIER_LSB          0x03
#define         MII_PHY_AUTONEGADVERTISEMENT    0x04
#define         MII_PHY_AUTONEGLINKPARTABILITY  0x05
#define         MII_PHY_AUTONEGEXPANSION        0x06
#define         MII_PHY_AUTONEGNP_TRANSMIT      0x07
#define         MII_PHY_AUTONEGLP_RECEIVE_NP    0x08
#define         MII_PHY_EXTENDED_STATUS         0x0F
 
/* NIC Physical Layer Device MII register fields. */
#define         MII_PHY_CONTROL_RESTARTAN       0x0200
#define         MII_PHY_SELECTORFIELD           0x001F
#define         MII_PHY_SELECTOR_IEEE8023       0x0001
#define         MII_PHY_TECHABILITYFIELD        0x1FE0
#define         MII_PHY_TECHABILITY_10BT        0x0020
#define         MII_PHY_TECHABILITY_10BTFD      0x0040
#define         MII_PHY_TECHABILITY_100BTX      0x0080
#define         MII_PHY_TECHABILITY_100BTXFD    0x0100
#define         MII_PHY_TECHABILITY_100BT4      0x0200
#define         MII_PHY_TECHABILITY_PAUSE_FIELDS 0x0C00
#define         MII_PHY_TECHABILITY_PAUSE       0x0400
#define         MII_PHY_TECHABILITY_ASM_DIR     0x0800
#define         MII_PHY_TECHABILITY_RSVD2       0x1000
#define         MII_PHY_STATUS_AUTONEG_ABILITY  0x0008

/* NIC Physical Layer Device GMII register addresses. */
#define         GMII_PHY_CONTROL                 0x00
#define         GMII_PHY_STATUS                  0x01
#define		GMII_PHY_ID_1                    0x02
#define         GMII_PHY_AUTONEGADVERTISEMENT    0x04
#define         GMII_PHY_AUTONEGLINKPARTABILITY  0x05
#define         GMII_PHY_AUTONEGEXPANSION        0x06
#define         GMII_PHY_AUTONEGNEXTPAGE         0x07
#define         GMII_PHY_AUTONEGLINKPARTNEXTPAGE 0x08
#define         GMII_PHY_EXTENDEDSTATUS          0x0F

#define         GMII_PHY_1000BASETCONTROL        0x09
#define         GMII_PHY_1000BASETSTATUS         0x0A

#define         GMII_PHY_1000BASETCONTROL_FULL_DUPLEX 0x0200
#define         GMII_PHY_1000BASETCONTROL_HALF_DUPLEX 0x0100
#define         GMII_PHY_1000BASETSTATUS_FULL_DUPLEX 0x0800
#define         GMII_PHY_1000BASETSTATUS_HALF_DUPLEX 0x0400

/* NIC Physical Layer Device GMII register Fields. */
#define         GMII_PHY_CONTROL_RESET          0x8000
#define         GMII_PHY_CONTROL_FULL_DUPLEX    0x0100
#define         GMII_PHY_STATUS_AUTONEG_ABILITY 0x0008
#define         GMII_PHY_ADV_FULL_DUPLEX        0x0020
#define         GMII_PHY_ADV_HALF_DUPLEX        0x0040
#define         GMII_PHY_ADV_PAUSE              0x0180
#define         GMII_PHY_ADV_PAUSE_PS1          0x0080
#define         GMII_PHY_ADV_ASM_DIR_PS2        0x0100

/* NIC Physical Layer Device GMII constants. */
#define         GMII_PREAMBLE                    0xFFFFFFFF
#define         GMII_ST                          0x1
#define         GMII_READ                        0x2
#define         GMII_WRITE                       0x1
#define         GMII_TA_READ_MASK                0x1
#define         GMII_TA_WRITE                    0x2

/* PCI register addresses. */
#define         TC902X_POWERMGMTCTRL		0x54
#define         TC902X_POWERMGMTCAP		0x52
#define         TC902X_NEXTITEMPTR		0x51
#define         TC902X_CAPID			0x50
#define         TC902X_MAXLAT			0x3F
#define         TC902X_MINGNT			0x3E
#define         TC902X_INTERRUPTPIN		0x3D
#define         TC902X_INTERRUPTLINE		0x3C
#define         TC902X_CAPPTR			0x34
#define         TC902X_EXPROMBASEADDRESS	0x30
#define         TC902X_SUBSYSTEMID		0x2E
#define         TC902X_SUBSYSTEMVENDORID	0x2C
#define         TC902X_MEMBASEADDRESS		0x14
#define         TC902X_IOBASEADDRESS		0x10
#define         TC902X_HEADERTYPE		0x0E
#define         TC902X_LATENCYTIMER		0x0D
#define         TC902X_CACHELINESIZE		0x0C
#define         TC902X_CLASSCODE		0x09
#define         TC902X_REVISIONID		0x08
#define         TC902X_CONFIGSTATUS		0x06
#define         TC902X_CONFIGCOMMAND		0x04
#define         TC902X_DEVICEID			0x02
#define         TC902X_VENDORID			0x00

/* I/O register offsets. */
#define	TC902X_DMACTRL			0x00
#define	TC902X_RXDMASTATUS		0x08 /* RESERVED */
#define	TC902X_TFDLISTPTR0		0x10
#define	TC902X_TFDLISTPTR1		0x14
#define	TC902X_TXDMABURSTTHRESH		0x18
#define	TC902X_TXDMAURGENTTHRESH	0x19
#define	TC902X_TXDMAPOLLPERIOD		0x1A
#define	TC902X_RFDLISTPTR0		0x1C
#define	TC902X_RFDLISTPTR1		0x20
#define	TC902X_RXDMABURSTTHRESH		0x24
#define	TC902X_RXDMAURGENTTHRESH	0x25
#define	TC902X_RXDMAPOLLPERIOD		0x26
#define	TC902X_RXDMAINTCTRL		0x28
#define	TC902X_DEBUGCTRL		0x2C
#define	TC902X_ASICCTRL			0x30
#define	TC902X_FIFOCTRL			0x38
#define	TC902X_RXEARLYTHRESH		0x3A
#define	TC902X_FLOWOFFTHRESH		0x3C
#define	TC902X_FLOWONTHRESH		0x3E
#define	TC902X_TXSTARTTHRESH		0x44
#define	TC902X_EEPROMDATA		0x48
#define	TC902X_EEPROMCTRL		0x4A
#define	TC902X_EXPROMADDR		0x4C
#define	TC902X_EXPROMDATA		0x50
#define	TC902X_WAKEEVENT		0x51
#define	TC902X_COUNTDOWN		0x54
#define	TC902X_INTSTATUSACK		0x5A
#define	TC902X_INTENABLE		0x5C
#define	TC902X_INTSTATUS		0x5E
#define	TC902X_TXSTATUS			0x60
#define	TC902X_MACCTRL			0x6C
#define	TC902X_VLANTAG			0x70
#define	TC902X_PHYCTRL			0x76
#define	TC902X_STATIONADDRESS0		0x78
#define	TC902X_STATIONADDRESS1		0x7A
#define	TC902X_STATIONADDRESS2		0x7C
#define	TC902X_MAXFRAMESIZE		0x86
#define	TC902X_RECEIVEMODE		0x88
#define	TC902X_HASHTABLE0		0x8C
#define	TC902X_HASHTABLE1		0x90
#define	TC902X_RMONSTATISTICSMASK	0x98
#define	TC902X_STATISTICSMASK		0x9C
#define	TC902X_RXJUMBOFRAMES		0xBC
#define	TC902X_TCPCHECKSUMERRORS	0xC0
#define	TC902X_IPCHECKSUMERRORS		0xC2
#define	TC902X_UDPCHECKSUMERRORS	0xC4
#define	TC902X_TXJUMBOFRAMES		0xF4

/* Ethernet MIB statistic register offsets. */
#define	TC902X_OCTETRCVOK		0xA8
#define	TC902X_MCSTOCTETRCVDOK		0xAC
#define	TC902X_BCSTOCTETRCVOK		0xB0
#define	TC902X_FRAMESRCVDOK		0xB4
#define	TC902X_MCSTFRAMESRCVDOK		0xB8
#define	TC902X_BCSTFRAMESRCVDOK		0xBE
#define	TC902X_MACCONTROLFRAMESRCVD	0xC6
#define	TC902X_FRAMETOOLONGERRRORS	0xC8
#define	TC902X_INRANGELENGTHERRORS	0xCA
#define	TC902X_FRAMECHECKSEQERRORS	0xCC
#define	TC902X_FRAMESLOSTRXERRORS	0xCE
#define	TC902X_OCTETXMTOK		0xD0
#define	TC902X_MCSTOCTETXMTOK		0xD4
#define	TC902X_BCSTOCTETXMTOK		0xD8
#define	TC902X_FRAMESXMTDOK		0xDC
#define	TC902X_MCSTFRAMESXMTDOK		0xE0
#define	TC902X_FRAMESWDEFERREDXMT	0xE4
#define	TC902X_LATECOLLISIONS		0xE8
#define	TC902X_MULTICOLFRAMES		0xEC
#define	TC902X_SINGLECOLFRAMES		0xF0
#define	TC902X_BCSTFRAMESXMTDOK		0xF6
#define	TC902X_CARRIERSENSEERRORS	0xF8
#define	TC902X_MACCONTROLFRAMESXMTDOK	0xFA
#define	TC902X_FRAMESABORTXSCOLLS	0xFC
#define	TC902X_FRAMESWEXDEFERRAL	0xFE

/* RMON statistic register offsets. */
#define	TC902X_ETHERSTATSCOLLISIONS			0x100
#define	TC902X_ETHERSTATSOCTETSTRANSMIT			0x104
#define	TC902X_ETHERSTATSPKTSTRANSMIT			0x108
#define	TC902X_ETHERSTATSPKTS64OCTESTSTRANSMIT		0x10C
#define	TC902X_ETHERSTATSPKTS65TO127OCTESTSTRANSMIT	0x110
#define	TC902X_ETHERSTATSPKTS128TO255OCTESTSTRANSMIT	0x114
#define	TC902X_ETHERSTATSPKTS256TO511OCTESTSTRANSMIT	0x118
#define	TC902X_ETHERSTATSPKTS512TO1023OCTESTSTRANSMIT	0x11C
#define	TC902X_ETHERSTATSPKTS1024TO1518OCTESTSTRANSMIT	0x120
#define	TC902X_ETHERSTATSCRCALIGNERRORS			0x124
#define	TC902X_ETHERSTATSUNDERSIZEPKTS			0x128
#define	TC902X_ETHERSTATSFRAGMENTS			0x12C
#define	TC902X_ETHERSTATSJABBERS			0x130
#define	TC902X_ETHERSTATSOCTETS				0x134
#define	TC902X_ETHERSTATSPKTS				0x138
#define	TC902X_ETHERSTATSPKTS64OCTESTS			0x13C
#define	TC902X_ETHERSTATSPKTS65TO127OCTESTS		0x140
#define	TC902X_ETHERSTATSPKTS128TO255OCTESTS		0x144
#define	TC902X_ETHERSTATSPKTS256TO511OCTESTS		0x148
#define	TC902X_ETHERSTATSPKTS512TO1023OCTESTS		0x14C
#define	TC902X_ETHERSTATSPKTS1024TO1518OCTESTS		0x150

/* RMON statistic register equivalents. */
#define	TC902X_ETHERSTATSMULTICASTPKTSTRANSMIT		0xE0
#define	TC902X_ETHERSTATSBROADCASTPKTSTRANSMIT		0xF6
#define	TC902X_ETHERSTATSMULTICASTPKTS			0xB8
#define	TC902X_ETHERSTATSBROADCASTPKTS			0xBE
#define	TC902X_ETHERSTATSOVERSIZEPKTS			0xC8
#define	TC902X_ETHERSTATSDROPEVENTS			0xCE

/* Serial EEPROM offsets */
#define	TC902X_EEPROM_CONFIGPARAM	0x00
#define	TC902X_EEPROM_ASICCTRL		0x01
#define	TC902X_EEPROM_SUBSYSTEMVENDORID	0x02
#define	TC902X_EEPROM_SUBSYSTEMID	0x03
#define	TC902X_EEPROM_STATIONADDRESS0	0x10
#define	TC902X_EEPROM_STATIONADDRESS1	0x11
#define	TC902X_EEPROM_STATIONADDRESS2	0x12


/* Register & data structure bit masks */

/* PCI register masks. */

/* IOBaseAddress */
#define         TC902X_PIB_RSVD_MASK		0xFFFFFE01
#define         TC902X_PIB_IOBASEADDRESS	0xFFFFFF00
#define         TC902X_PIB_IOBASEADDRIND	0x00000001

/* MemBaseAddress */
#define         TC902X_PMB_RSVD_MASK		0xFFFFFE07
#define         TC902X_PMB_MEMBASEADDRIND	0x00000001
#define         TC902X_PMB_MEMMAPTYPE		0x00000006
#define         TC902X_PMB_MEMMAPTYPE0		0x00000002
#define         TC902X_PMB_MEMMAPTYPE1		0x00000004
#define         TC902X_PMB_MEMBASEADDRESS	0xFFFFFE00

/* ConfigStatus */
#define TC902X_CS_RSVD_MASK                0xFFB0
#define TC902X_CS_CAPABILITIES             0x0010
#define TC902X_CS_66MHZCAPABLE             0x0020
#define TC902X_CS_FASTBACK2BACK            0x0080
#define TC902X_CS_DATAPARITYREPORTED       0x0100
#define TC902X_CS_DEVSELTIMING             0x0600
#define TC902X_CS_SIGNALEDTARGETABORT      0x0800
#define TC902X_CS_RECEIVEDTARGETABORT      0x1000
#define TC902X_CS_RECEIVEDMASTERABORT      0x2000
#define TC902X_CS_SIGNALEDSYSTEMERROR      0x4000
#define TC902X_CS_DETECTEDPARITYERROR      0x8000

/* TFD data structure masks. */

/* TFDList, TFC */
#define	TC902X_TFC_RSVD_MASK			0x0000FFFF9FFFFFFF
#define	TC902X_TFC_FRAMEID			0x000000000000FFFF
#define	TC902X_TFC_WORDALIGN			0x0000000000030000
#define	TC902X_TFC_WORDALIGNTODWORD		0x0000000000000000
#define	TC902X_TFC_WORDALIGNTOWORD		0x0000000000020000
#define	TC902X_TFC_WORDALIGNDISABLED		0x0000000000030000
#define	TC902X_TFC_TCPCHECKSUMENABLE		0x0000000000040000
#define	TC902X_TFC_UDPCHECKSUMENABLE		0x0000000000080000
#define	TC902X_TFC_IPCHECKSUMENABLE		0x0000000000100000
#define	TC902X_TFC_FCSAPPENDDISABLE		0x0000000000200000
#define	TC902X_TFC_TXINDICATE			0x0000000000400000
#define	TC902X_TFC_TXDMAINDICATE		0x0000000000800000
#define	TC902X_TFC_FRAGCOUNT			0x000000000F000000
#define	TC902X_TFC_VLANTAGINSERT		0x0000000010000000
#define	TC902X_TFC_TFDDONE			0x0000000080000000
#define	TC902X_TFC_VID				0x00000FFF00000000
#define	TC902X_TFC_CFI				0x0000100000000000
#define	TC902X_TFC_USERPRIORITY			0x0000E00000000000

/* TFDList, FragInfo */
#define	TC902X_TFI_RSVD_MASK			0xFFFF00FFFFFFFFFF
#define	TC902X_TFI_FRAGADDR			0x000000FFFFFFFFFF
#define	TC902X_TFI_FRAGLEN			0xFFFF000000000000

/* RFD data structure masks. */

/* RFDList, RFS */
#define	TC902X_RFS_RSVD_MASK			0x0000FFFFFFFFFFFF
#define	TC902X_RFS_RXFRAMELEN			0x000000000000FFFF
#define	TC902X_RFS_RXFIFOOVERRUN		0x0000000000010000
#define	TC902X_RFS_RXRUNTFRAME			0x0000000000020000
#define	TC902X_RFS_RXALIGNMENTERROR		0x0000000000040000
#define	TC902X_RFS_RXFCSERROR			0x0000000000080000
#define	TC902X_RFS_RXOVERSIZEDFRAME		0x0000000000100000
#define	TC902X_RFS_RXLENGTHERROR		0x0000000000200000
#define	TC902X_RFS_VLANDETECTED			0x0000000000400000
#define	TC902X_RFS_TCPDETECTED			0x0000000000800000
#define	TC902X_RFS_TCPERROR			0x0000000001000000
#define	TC902X_RFS_UDPDETECTED			0x0000000002000000
#define	TC902X_RFS_UDPERROR			0x0000000004000000
#define	TC902X_RFS_IPDETECTED			0x0000000008000000
#define	TC902X_RFS_IPERROR			0x0000000010000000
#define	TC902X_RFS_FRAMESTART			0x0000000020000000
#define	TC902X_RFS_FRAMEEND			0x0000000040000000
#define	TC902X_RFS_RFDDONE			0x0000000080000000
#define	TC902X_RFS_TCI				0x0000FFFF00000000


/* RFDList, FragInfo */
#define	TC902X_RFI_RSVD_MASK			0xFFFF00FFFFFFFFFF
#define	TC902X_RFI_FRAGADDR			0x000000FFFFFFFFFF
#define	TC902X_RFI_FRAGLEN			0xFFFF000000000000

/* I/O Register masks. */

/* RMON Statistics Mask */
#define	TC902X_RZ_ALL					0x0FFFFFFF

/* Statistics Mask */
#define	TC902X_SM_ALL					0x0FFFFFFF
#define	TC902X_SM_OCTETRCVOK_FRAMESRCVDOK		0x00000001
#define	TC902X_SM_MCSTOCTETRCVDOK_MCSTFRAMESRCVDOK	0x00000002
#define	TC902X_SM_BCSTOCTETRCVDOK_BCSTFRAMESRCVDOK	0x00000004
#define	TC902X_SM_RXJUMBOFRAMES				0x00000008
#define	TC902X_SM_TCPCHECKSUMERRORS			0x00000010
#define	TC902X_SM_IPCHECKSUMERRORS			0x00000020
#define	TC902X_SM_UDPCHECKSUMERRORS			0x00000040
#define	TC902X_SM_MACCONTROLFRAMESRCVD			0x00000080
#define	TC902X_SM_FRAMESTOOLONGERRORS			0x00000100
#define	TC902X_SM_INRANGELENGTHERRORS			0x00000200
#define	TC902X_SM_FRAMECHECKSEQERRORS			0x00000400
#define	TC902X_SM_FRAMESLOSTRXERRORS			0x00000800
#define	TC902X_SM_OCTETXMTOK_FRAMESXMTOK		0x00001000
#define	TC902X_SM_MCSTOCTETXMTOK_MCSTFRAMESXMTDOK	0x00002000
#define	TC902X_SM_BCSTOCTETXMTOK_BCSTFRAMESXMTDOK	0x00004000
#define	TC902X_SM_FRAMESWDEFERREDXMT			0x00008000
#define	TC902X_SM_LATECOLLISIONS			0x00010000
#define	TC902X_SM_MULTICOLFRAMES			0x00020000
#define	TC902X_SM_SINGLECOLFRAMES			0x00040000
#define	TC902X_SM_TXJUMBOFRAMES				0x00080000
#define	TC902X_SM_CARRIERSENSEERRORS			0x00100000
#define	TC902X_SM_MACCONTROLFRAMESXMTD			0x00200000
#define	TC902X_SM_FRAMESABORTXSCOLLS			0x00400000
#define	TC902X_SM_FRAMESWEXDEFERAL			0x00800000


/* Countdown */
#define	TC902X_CD_RSVD_MASK		0x0700FFFF
#define	TC902X_CD_COUNT			0x0000FFFF
#define	TC902X_CD_COUNTDOWNSPEED	0x01000000
#define	TC902X_CD_COUNTDOWNMODE		0x02000000
#define	TC902X_CD_COUNTINTENABLED	0x04000000

/* TxDMABurstThresh */
#define TC902X_TB_RSVD_MASK                0xFF

/* TxDMAUrgentThresh */
#define TC902X_TU_RSVD_MASK                0xFF

/* TxDMAPollPeriod */
#define TC902X_TP_RSVD_MASK                0xFF

/* RxDMAUrgentThresh */
#define TC902X_RU_RSVD_MASK                0xFF

/* RxDMAPollPeriod */
#define TC902X_RP_RSVD_MASK                0xFF

/* TxStartThresh */
#define TC902X_TT_RSVD_MASK                0x0FFF

/* RxEarlyThresh */
#define TC902X_RE_RSVD_MASK                0x07FF

/* ReceiveMode */
#define TC902X_RM_RSVD_MASK                0x3F
#define TC902X_RM_RECEIVEUNICAST           0x01
#define TC902X_RM_RECEIVEMULTICAST         0x02
#define TC902X_RM_RECEIVEBROADCAST         0x04
#define TC902X_RM_RECEIVEALLFRAMES         0x08
#define TC902X_RM_RECEIVEMULTICASTHASH     0x10
#define TC902X_RM_RECEIVEIPMULTICAST       0x20

/* PhyCtrl */
#define TC902X_PC_RSVD_MASK                0xFF
#define TC902X_PC_MGMTCLK_LO               0x00
#define TC902X_PC_MGMTCLK_HI               0x01
#define TC902X_PC_MGMTCLK                  0x01
#define TC902X_PC_MGMTDATA                 0x02
#define TC902X_PC_MGMTDIR                  0x04
#define TC902X_PC_DUPLEX_POLARITY          0x08
#define TC902X_PC_DUPLEX_STATUS            0x10
#define TC902X_PC_LINK_POLARITY            0x20
#define TC902X_PC_LINK_SPEED               0xC0
#define TC902X_PC_LINK_SPEED_10MBPS        0x40
#define TC902X_PC_LINK_SPEED_100MBPS       0x80
#define TC902X_PC_LINK_SPEED_1000MBPS      0xC0

/* DMACtrl */
#define TC902X_DC_RSVD_MASK                0xC07D9818
#define TC902X_DC_RX_DMA_COMPLETE          0x00000008
#define TC902X_DC_RX_DMA_POLL_NOW          0x00000010
#define TC902X_DC_TX_DMA_COMPLETE          0x00000800
#define TC902X_DC_TX_DMA_POLL_NOW          0x00001000
#define TC902X_DC_TX_DMA_IN_PROG           0x00008000
#define TC902X_DC_RX_EARLY_DISABLE         0x00010000
#define TC902X_DC_MWI_DISABLE              0x00040000
#define TC902X_DC_TX_WRITE_BACK_DISABLE    0x00080000
#define TC902X_DC_TX_BURST_LIMIT           0x00700000
#define TC902X_DC_TARGET_ABORT             0x40000000
#define TC902X_DC_MASTER_ABORT             0x80000000

/* ASICCtrl */
#define TC902X_AC_RSVD_MASK                0x07FFEFF2
#define TC902X_AC_EXP_ROM_SIZE             0x00000002
#define TC902X_AC_PHY_SPEED10              0x00000010
#define TC902X_AC_PHY_SPEED100             0x00000020
#define TC902X_AC_PHY_SPEED1000            0x00000040
#define TC902X_AC_PHY_MEDIA                0x00000080
#define TC902X_AC_FORCED_CFG               0x00000700
#define TC902X_AC_D3RESETDISABLE           0x00000800
#define TC902X_AC_SPEED_UP_MODE            0x00002000
#define TC902X_AC_LED_MODE                 0x00004000
#define TC902X_AC_RST_OUT_POLARITY         0x00008000
#define TC902X_AC_GLOBAL_RESET             0x00010000
#define TC902X_AC_RX_RESET                 0x00020000
#define TC902X_AC_TX_RESET                 0x00040000
#define TC902X_AC_DMA                      0x00080000
#define TC902X_AC_FIFO                     0x00100000
#define TC902X_AC_NETWORK                  0x00200000
#define TC902X_AC_HOST                     0x00400000
#define TC902X_AC_AUTO_INIT                0x00800000
#define TC902X_AC_RST_OUT                  0x01000000
#define TC902X_AC_INT_REQUEST              0x02000000
#define TC902X_AC_RESET_BUSY               0x04000000

/* EepromCtrl */
#define TC902X_EC_RSVD_MASK                0x83FF
#define TC902X_EC_EEPROM_ADDR              0x00FF
#define TC902X_EC_EEPROM_OPCODE            0x0300
#define TC902X_EC_EEPROM_SUBCOMMAD         0x0000
#define TC902X_EC_EEPROM_WRITEOPCODE       0x0100
#define TC902X_EC_EEPROM_READOPCODE        0x0200
#define TC902X_EC_EEPROM_ERASEOPCODE       0x0300
#define TC902X_EC_EEPROM_BUSY              0x8000

/* FIFOCtrl */
#define TC902X_FC_RSVD_MASK                0xC001
#define TC902X_FC_RAM_TEST_MODE            0x0001
#define TC902X_FC_TRANSMITTING             0x4000
#define TC902X_FC_RECEIVING                0x8000

/* TxStatus */
#define TC902X_TS_RSVD_MASK                0xFFFF00DD
#define TC902X_TS_TX_ERROR                 0x00000001
#define TC902X_TS_LATE_COLLISION           0x00000004
#define TC902X_TS_TX_MAX_COLL              0x00000008
#define TC902X_TS_TX_UNDERRUN              0x00000010
#define TC902X_TS_TX_IND_REQD              0x00000040
#define TC902X_TS_TX_COMPLETE              0x00000080
#define TC902X_TS_TX_FRAMEID               0xFFFF0000

/* WakeEvent */
#define TC902X_WE_WAKE_PKT_ENABLE          0x01
#define TC902X_WE_MAGIC_PKT_ENABLE         0x02
#define TC902X_WE_LINK_EVT_ENABLE          0x04
#define TC902X_WE_WAKE_POLARITY            0x08
#define TC902X_WE_WAKE_PKT_EVT             0x10
#define TC902X_WE_MAGIC_PKT_EVT            0x20
#define TC902X_WE_LINK_EVT                 0x40
#define TC902X_WE_WOL_ENABLE               0x80

/* IntEnable */
#define TC902X_IE_RSVD_MASK                0x1FFE
#define TC902X_IE_HOST_ERROR               0x0002
#define TC902X_IE_TX_COMPLETE              0x0004
#define TC902X_IE_MAC_CTRL_FRAME           0x0008
#define TC902X_IE_RX_COMPLETE              0x0010
#define TC902X_IE_RX_EARLY                 0x0020
#define TC902X_IE_INT_REQUESTED            0x0040
#define TC902X_IE_UPDATE_STATS             0x0080
#define TC902X_IE_LINK_EVENT               0x0100
#define TC902X_IE_TX_DMA_COMPLETE          0x0200
#define TC902X_IE_RX_DMA_COMPLETE          0x0400
#define TC902X_IE_RFD_LIST_END             0x0800
#define TC902X_IE_RX_DMA_PRIORITY          0x1000

/* IntStatus */
#define TC902X_IS_RSVD_MASK                0x1FFF
#define TC902X_IS_INTERRUPT_STATUS         0x0001
#define TC902X_IS_HOST_ERROR               0x0002
#define TC902X_IS_TX_COMPLETE              0x0004
#define TC902X_IS_MAC_CTRL_FRAME           0x0008
#define TC902X_IS_RX_COMPLETE              0x0010
#define TC902X_IS_RX_EARLY                 0x0020
#define TC902X_IS_INT_REQUESTED            0x0040
#define TC902X_IS_UPDATE_STATS             0x0080
#define TC902X_IS_LINK_EVENT               0x0100
#define TC902X_IS_TX_DMA_COMPLETE          0x0200
#define TC902X_IS_RX_DMA_COMPLETE          0x0400
#define TC902X_IS_RFD_LIST_END             0x0800
#define TC902X_IS_RX_DMA_PRIORITY          0x1000

/* MACCtrl */
#define TC902X_MC_RSVD_MASK                0x7FE33FA3
#define TC902X_MC_IFS_SELECT               0x00000003
#define TC902X_MC_IFS_4352BIT              0x00000003
#define TC902X_MC_IFS_1792BIT              0x00000002
#define TC902X_MC_IFS_1024BIT              0x00000001
#define TC902X_MC_IFS_96BIT                0x00000000
#define TC902X_MC_DUPLEX_SELECT            0x00000020
#define TC902X_MC_DUPLEX_SELECT_FD         0x00000020
#define TC902X_MC_DUPLEX_SELECT_HD         0x00000000
#define TC902X_MC_TX_FLOW_CONTROL_ENABLE   0x00000080
#define TC902X_MC_RX_FLOW_CONTROL_ENABLE   0x00000100
#define TC902X_MC_RCV_FCS                  0x00000200
#define TC902X_MC_FIFO_LOOPBACK            0x00000400
#define TC902X_MC_MAC_LOOPBACK             0x00000800
#define TC902X_MC_AUTO_VLAN_TAGGING        0x00001000
#define TC902X_MC_AUTO_VLAN_UNTAGGING      0x00002000
#define TC902X_MC_COLLISION_DETECT         0x00010000
#define TC902X_MC_CARRIER_SENSE            0x00020000
#define TC902X_MC_STATISTICS_ENABLE        0x00200000
#define TC902X_MC_STATISTICS_DISABLE       0x00400000
#define TC902X_MC_STATISTICS_ENABLED       0x00800000
#define TC902X_MC_TX_ENABLE                0x01000000
#define TC902X_MC_TX_DISABLE               0x02000000
#define TC902X_MC_TX_ENABLED               0x04000000
#define TC902X_MC_RX_ENABLE                0x08000000
#define TC902X_MC_RX_DISABLE               0x10000000
#define TC902X_MC_RX_ENABLED               0x20000000
#define TC902X_MC_PAUSED                   0x40000000

/* RxDMAIntCtrl */
#define TC902X_RI_RSVD_MASK                0xFFFF1CFF
#define TC902X_RI_RXFRAME_COUNT            0x000000FF
#define TC902X_RI_PRIORITY_THRESH          0x00001C00
#define TC902X_RI_RXDMAWAIT_TIME           0xFFFF0000

/* end tc902x_constants.h */
